==> kotlin-web-site-ui-4.2.0-alpha.4.tgz: package/out/components/top-menu/vertical-menu/vertical-menu.js <==
import React__default, { useState, useCallback, useEffect, useRef, useLayoutEffect } from 'react';
import classNames from 'classnames';
import styles from './vertical-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';
import SvgArrowDropdownIcon from './arrow-dropdown-icon.svg.js';
import { useTheme } from '@rescui/ui-contexts';
import Button from '@rescui/button';
import { CloseIcon } from '@rescui/icons';
import { disableBodyScroll, clearAllBodyScrollLocks } from 'body-scroll-lock';
import { createPortal } from 'react-dom';

const VerticalMenu = ({
  homeUrl,
  title,
  mobileTitle = 'Overview',
  items,
  activeIndex,
  linkHandler,
  mobileOverview = true,
  topMenuRef
}) => {
  const textCn = useTextStyles();

  let _items = (mobileOverview ? [{
    title: mobileTitle,
    url: homeUrl
  }] : []).concat(items);

  const _activeIndex = mobileOverview ? activeIndex + 1 : activeIndex;

  const activeItem = _items[_activeIndex];
  const [isExpanded, setIsExpanded] = useState(false);
  const [portalRoot, setPortalRoot] = useState(null);
  const handleOpen = useCallback(() => {
    setIsExpanded(true);
  }, []);
  const handleClose = useCallback(() => {
    setIsExpanded(false);
  }, []);
  useEffect(() => {
    if (typeof document !== `undefined`) {
      setPortalRoot(document.body);
    }
  }, []);
  return React__default.createElement(React__default.Fragment, null, React__default.createElement("div", {
    className: classNames(styles.dropdownMenu, {
      [styles.dropdownMenuExpanded]: isExpanded
    })
  }, React__default.createElement("button", {
    className: classNames(styles.button, textCn('rs-text-2')),
    "aria-haspopup": "true",
    onClick: handleOpen
  }, React__default.createElement("span", {
    className: styles.buttonText
  }, activeItem.title), React__default.createElement(SvgArrowDropdownIcon, {
    className: styles.icon
  })), !!portalRoot && isExpanded && createPortal(React__default.createElement(VerticalMenuDropDown, {
    title: title,
    activeIndex: _activeIndex,
    items: _items,
    onClose: handleClose,
    linkHandler: linkHandler,
    topMenuRef: topMenuRef
  }), portalRoot)));
};

const VerticalMenuDropDown = ({
  title,
  onClose,
  items,
  linkHandler,
  activeIndex,
  topMenuRef
}) => {
  const textCn = useTextStyles();
  const theme = useTheme();
  const navRef = useRef(null);
  const [navStyle, setNavStyle] = useState({});
  useEffect(() => {
    if (navRef.current) {
      disableBodyScroll(navRef.current);
    }

    return clearAllBodyScrollLocks;
  }, []);
  useLayoutEffect(() => {
    if (topMenuRef.current) {
      setNavStyle({
        top: topMenuRef.current.getBoundingClientRect().top
      });
    }
  }, [topMenuRef]);
  return React__default.createElement("nav", {
    ref: navRef,
    style: navStyle,
    className: classNames(styles.dropdownList, {
      [styles.dropdownListDarkTheme]: theme === 'dark'
    })
  }, React__default.createElement("div", {
    className: styles.dropdownHeader
  }, React__default.createElement("div", {
    className: textCn('rs-text-2')
  }, title), React__default.createElement(Button, {
    mode: 'clear',
    size: 'l',
    icon: React__default.createElement(CloseIcon, null),
    onClick: onClose
  })), items.map((item, index) => React__default.createElement("a", {
    key: item.url,
    href: item.url,
    className: classNames(styles.dropdownItem, textCn('rs-text-1'), {
      [styles.dropdownItemActive]: index === activeIndex
    }),
    onClick: event => linkHandler?.(event, item.url),
    target: item.isExternal ? '_blank' : undefined
  }, item.title)));
};

export { VerticalMenu };

==> kotlin-web-site-ui-4.4.0-alpha.4.tgz: package/out/components/top-menu/vertical-menu/vertical-menu.js <==
import React__default, { useState, useCallback, useEffect, useRef, useLayoutEffect } from 'react';
import classNames from 'classnames';
import styles from './vertical-menu.module.pcss.js';
import { useTextStyles } from '@rescui/typography';
import SvgArrowDropdownIcon from './arrow-dropdown-icon.svg.js';
import { useTheme } from '@rescui/ui-contexts';
import Button from '@rescui/button';
import { CloseIcon } from '@rescui/icons';
import { disableBodyScroll, clearAllBodyScrollLocks } from 'body-scroll-lock';
import { createPortal } from 'react-dom';

const VerticalMenu = ({
  homeUrl,
  title,
  mobileTitle = 'Overview',
  items,
  activeIndex,
  linkHandler,
  mobileOverview = true,
  topMenuRef
}) => {
  const textCn = useTextStyles();

  const _items = (mobileOverview ? [{
    title: mobileTitle,
    url: homeUrl
  }] : []).concat(items);

  const _activeIndex = mobileOverview ? activeIndex + 1 : activeIndex;

  const activeItem = _items[_activeIndex];
  const [isExpanded, setIsExpanded] = useState(false);
  const [portalRoot, setPortalRoot] = useState(null);
  const [isTopMenuSticky, setIsTopMenuSticky] = useState(false);
  const handleOpen = useCallback(() => {
    setIsExpanded(true);
    const topMenuTopOffset = topMenuRef?.current?.getBoundingClientRect().top;
    setIsTopMenuSticky(topMenuTopOffset === 0);
  }, []);
  const handleClose = useCallback(() => {
    setIsExpanded(false);
  }, []);
  useEffect(() => {
    if (typeof document !== `undefined`) {
      setPortalRoot(document.body);
    }
  }, []);
  return React__default.createElement(React__default.Fragment, null, React__default.createElement("div", {
    className: classNames(styles.dropdownMenu, {
      [styles.dropdownMenuExpanded]: isExpanded
    })
  }, React__default.createElement("button", {
    className: classNames(styles.button),
    "aria-haspopup": "true",
    onClick: handleOpen
  }, React__default.createElement("span", {
    className: textCn('rs-text-2', {
      hardness: 'hard'
    })
  }, activeItem.title), React__default.createElement(SvgArrowDropdownIcon, {
    className: styles.icon
  })), !!portalRoot && isExpanded && createPortal(React__default.createElement(VerticalMenuDropDown, {
    title: title,
    activeIndex: _activeIndex,
    items: _items,
    onClose: handleClose,
    linkHandler: linkHandler,
    topMenuRef: topMenuRef,
    isSticky: isTopMenuSticky
  }), portalRoot)));
};

const VerticalMenuDropDown = ({
  title,
  onClose,
  items,
  linkHandler,
  activeIndex,
  topMenuRef,
  isSticky
}) => {
  const textCn = useTextStyles();
  const theme = useTheme();
  const navRef = useRef(null);
  const [navStyle, setNavStyle] = useState({});
  useEffect(() => {
    if (navRef.current) {
      disableBodyScroll(navRef.current);
    }

    return clearAllBodyScrollLocks;
  }, []);
  useLayoutEffect(() => {
    if (topMenuRef.current) {
      setNavStyle({
        top: topMenuRef.current.getBoundingClientRect().top
      });
    }
  }, [topMenuRef]);
  return React__default.createElement("nav", {
    ref: navRef,
    style: navStyle,
    className: classNames(styles.dropdownList, {
      [styles.dropdownListDarkTheme]: theme === 'dark'
    })
  }, React__default.createElement("div", {
    className: classNames(styles.dropdownHeader, {
      [styles.stickyHeader]: !isSticky
    })
  }, React__default.createElement("div", {
    className: textCn('rs-text-2')
  }, title), React__default.createElement(Button, {
    mode: 'clear',
    size: 'l',
    icon: React__default.createElement(CloseIcon, null),
    onClick: onClose
  })), items.map((item, index) => React__default.createElement("a", {
    key: item.url,
    href: item.url,
    className: classNames(styles.dropdownItem, textCn('rs-text-1', {
      hardness: 'hard'
    }), {
      [styles.dropdownItemActive]: index === activeIndex
    }),
    onClick: event => linkHandler?.(event, item.url),
    target: item.isExternal ? '_blank' : undefined,
    rel: "noreferrer"
  }, item.title)));
};

export { VerticalMenu };
